ArchGenConfig class
Constructors
- ArchGenConfig({required String stateManagement})
- Whether to use Equatable package with BLoC Creates a new configuration instance.
- ArchGenConfig.fromYaml(Map yaml)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stateManagement → String
-
State management solution: 'bloc' or 'riverpod'
final
Methods
-
copyWith(
{String? stateManagement}) → ArchGenConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited